summaryrefslogtreecommitdiffstats
path: root/src/projectmanager.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:57:14 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:57:14 -0600
commitc1ef065782051db96cdfd32cf55be6408c2a9d22 (patch)
tree0bc3705b597f8c98b2b9992d22ab9620df50b877 /src/projectmanager.cpp
parentbab171b2a7d7f36e2d5dd510df80fc8cb4a6b06f (diff)
downloadktechlab-c1ef065782051db96cdfd32cf55be6408c2a9d22.tar.gz
ktechlab-c1ef065782051db96cdfd32cf55be6408c2a9d22.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit bab171b2a7d7f36e2d5dd510df80fc8cb4a6b06f.
Diffstat (limited to 'src/projectmanager.cpp')
-rw-r--r--src/projectmanager.cpp76
1 files changed, 38 insertions, 38 deletions
diff --git a/src/projectmanager.cpp b/src/projectmanager.cpp
index 2bdca82..3a6565c 100644
--- a/src/projectmanager.cpp
+++ b/src/projectmanager.cpp
@@ -192,11 +192,11 @@ ProjectItem::ProjectItem( ProjectItem * parent, Type type, ProjectManager * proj
ProjectItem::~ProjectItem()
{
- m_children.remove( (ProjectItem*)0l );
- ProjectItemList::iterator end = m_children.end();
- for ( ProjectItemList::iterator it = m_children.begin(); it != end; ++it )
+ m_tqchildren.remove( (ProjectItem*)0l );
+ ProjectItemList::iterator end = m_tqchildren.end();
+ for ( ProjectItemList::iterator it = m_tqchildren.begin(); it != end; ++it )
(*it)->deleteLater();
- m_children.clear();
+ m_tqchildren.clear();
delete m_pILVItem;
m_pILVItem = 0l;
@@ -254,10 +254,10 @@ void ProjectItem::updateILVItemPixmap()
void ProjectItem::addChild( ProjectItem * child )
{
- if ( !child || m_children.contains(child) )
+ if ( !child || m_tqchildren.contains(child) )
return;
- m_children << child;
+ m_tqchildren << child;
child->setILVItem( m_pILVItem ?
new ILVItem( m_pILVItem, child->name() ) :
@@ -283,9 +283,9 @@ void ProjectItem::updateControlChildMicroIDs()
break;
}
- m_children.remove( (ProjectItem*)0l );
- ProjectItemList::iterator end = m_children.end();
- for ( ProjectItemList::iterator it = m_children.begin(); it != end; ++it )
+ m_tqchildren.remove( (ProjectItem*)0l );
+ ProjectItemList::iterator end = m_tqchildren.end();
+ for ( ProjectItemList::iterator it = m_tqchildren.begin(); it != end; ++it )
(*it)->setUseParentMicroID( control );
}
@@ -420,7 +420,7 @@ bool ProjectItem::build( ProcessOptionsList * pol )
if ( outputURL().isEmpty() )
{
- KMessageBox::sorry( 0l, i18n("Don't know how to build \"%1\" (output url is empty).").arg(name()) );
+ KMessageBox::sorry( 0l, i18n("Don't know how to build \"%1\" (output url is empty).").tqarg(name()) );
return false;
}
@@ -431,7 +431,7 @@ bool ProjectItem::build( ProcessOptionsList * pol )
ProjectItem * lib = projectInfo->findItem( projectInfo->directory() + *it );
if ( !lib )
{
- KMessageBox::sorry( 0l, i18n("Don't know how to build \"%1\" (library does not exist in project).").arg(*it) );
+ KMessageBox::sorry( 0l, i18n("Don't know how to build \"%1\" (library does not exist in project).").tqarg(*it) );
return false;
}
@@ -440,10 +440,10 @@ bool ProjectItem::build( ProcessOptionsList * pol )
}
- // Build all children
- m_children.remove( (ProjectItem*)0l );
- ProjectItemList::iterator cend = m_children.end();
- for ( ProjectItemList::iterator it = m_children.begin(); it != cend; ++it )
+ // Build all tqchildren
+ m_tqchildren.remove( (ProjectItem*)0l );
+ ProjectItemList::iterator cend = m_tqchildren.end();
+ for ( ProjectItemList::iterator it = m_tqchildren.begin(); it != cend; ++it )
{
if ( ! (*it)->build(pol) )
return false;
@@ -461,7 +461,7 @@ bool ProjectItem::build( ProcessOptionsList * pol )
switch ( outputType() )
{
case UnknownOutput:
- KMessageBox::sorry( 0l, i18n("Don't know how to build \"%1\" (unknown output type).").arg(name()) );
+ KMessageBox::sorry( 0l, i18n("Don't know how to build \"%1\" (unknown output type).").tqarg(name()) );
return false;
case ProgramOutput:
@@ -494,9 +494,9 @@ bool ProjectItem::build( ProcessOptionsList * pol )
TQStringList inputFiles;
// Link child objects
- m_children.remove( (ProjectItem*)0l );
- ProjectItemList::iterator cend = m_children.end();
- for ( ProjectItemList::iterator it = m_children.begin(); it != cend; ++it )
+ m_tqchildren.remove( (ProjectItem*)0l );
+ ProjectItemList::iterator cend = m_tqchildren.end();
+ for ( ProjectItemList::iterator it = m_tqchildren.begin(); it != cend; ++it )
inputFiles << (*it)->outputURL().path();
po.setInputFiles(inputFiles);
@@ -565,8 +565,8 @@ TQDomElement ProjectItem::toDomElement( TQDomDocument & doc, const KURL & baseUR
node.appendChild( ProcessingOptions::toDomElement( doc, baseURL ) );
- ProjectItemList::const_iterator end = m_children.end();
- for ( ProjectItemList::const_iterator it = m_children.begin(); it != end; ++it )
+ ProjectItemList::const_iterator end = m_tqchildren.end();
+ for ( ProjectItemList::const_iterator it = m_tqchildren.begin(); it != end; ++it )
{
if (*it)
node.appendChild( (*it)->toDomElement( doc, baseURL ) );
@@ -580,8 +580,8 @@ KURL::List ProjectItem::childOutputURLs( unsigned types, unsigned outputTypes )
{
KURL::List urls;
- ProjectItemList::const_iterator end = m_children.end();
- for ( ProjectItemList::const_iterator it = m_children.begin(); it != end; ++it )
+ ProjectItemList::const_iterator end = m_tqchildren.end();
+ for ( ProjectItemList::const_iterator it = m_tqchildren.begin(); it != end; ++it )
{
if (!*it)
continue;
@@ -601,8 +601,8 @@ ProjectItem * ProjectItem::findItem( const KURL & url )
if ( this->url() == url )
return this;
- ProjectItemList::const_iterator end = m_children.end();
- for ( ProjectItemList::const_iterator it = m_children.begin(); it != end; ++it )
+ ProjectItemList::const_iterator end = m_tqchildren.end();
+ for ( ProjectItemList::const_iterator it = m_tqchildren.begin(); it != end; ++it )
{
if (!*it)
continue;
@@ -622,9 +622,9 @@ bool ProjectItem::closeOpenFiles()
if ( doc && !doc->fileClose() )
return false;
- m_children.remove( (ProjectItem*)0l );
- ProjectItemList::iterator end = m_children.end();
- for ( ProjectItemList::iterator it = m_children.begin(); it != end; ++it )
+ m_tqchildren.remove( (ProjectItem*)0l );
+ ProjectItemList::iterator end = m_tqchildren.end();
+ for ( ProjectItemList::iterator it = m_tqchildren.begin(); it != end; ++it )
{
if ( !(*it)->closeOpenFiles() )
return false;
@@ -668,9 +668,9 @@ void ProjectItem::addFile( const KURL & url )
if ( url.isEmpty() )
return;
- m_children.remove( (ProjectItem*)0l );
- ProjectItemList::iterator end = m_children.end();
- for ( ProjectItemList::iterator it = m_children.begin(); it != end; ++it )
+ m_tqchildren.remove( (ProjectItem*)0l );
+ ProjectItemList::iterator end = m_tqchildren.end();
+ for ( ProjectItemList::iterator it = m_tqchildren.begin(); it != end; ++it )
{
if ( (*it)->type() == FileType && (*it)->url() == url )
return;
@@ -788,7 +788,7 @@ bool ProjectInfo::open( const KURL & url )
TQFile file(target);
if ( !file.open( IO_ReadOnly ) )
{
- KMessageBox::sorry( 0l, i18n("Could not open %1 for reading").arg(target) );
+ KMessageBox::sorry( 0l, i18n("Could not open %1 for reading").tqarg(target) );
return false;
}
@@ -805,7 +805,7 @@ bool ProjectInfo::open( const KURL & url )
TQString errorMessage;
if ( !doc.setContent( xml, &errorMessage ) )
{
- KMessageBox::sorry( 0l, i18n("Couldn't parse xml:\n%1").arg(errorMessage) );
+ KMessageBox::sorry( 0l, i18n("Couldn't parse xml:\n%1").tqarg(errorMessage) );
return false;
}
@@ -845,7 +845,7 @@ bool ProjectInfo::save()
TQFile file( m_url.path() );
if ( file.open(IO_WriteOnly) == false )
{
- KMessageBox::sorry( NULL, i18n("Project could not be saved to \"%1\"").arg(m_url.path()), i18n("Saving Project") );
+ KMessageBox::sorry( NULL, i18n("Project could not be saved to \"%1\"").tqarg(m_url.path()), i18n("Saving Project") );
return false;
}
@@ -857,9 +857,9 @@ bool ProjectInfo::save()
// root.appendChild( LinkerOptions::toDomElement(doc) );
// root.appendChild( ProcessingOptions::toDomElement(doc) );
- m_children.remove( (ProjectItem*)0l );
- ProjectItemList::const_iterator end = m_children.end();
- for ( ProjectItemList::const_iterator it = m_children.begin(); it != end; ++it )
+ m_tqchildren.remove( (ProjectItem*)0l );
+ ProjectItemList::const_iterator end = m_tqchildren.end();
+ for ( ProjectItemList::const_iterator it = m_tqchildren.begin(); it != end; ++it )
root.appendChild( (*it)->toDomElement( doc, m_url ) );
TQTextStream stream(&file);
@@ -1130,7 +1130,7 @@ void ProjectManager::slotRemoveSelected()
if ( !currentItem )
return;
- int choice = KMessageBox::questionYesNo( this, i18n("Do you really want to remove \"%1\"?").arg( currentItem->text(0) ), i18n("Remove Project File?"), KGuiItem(i18n("Remove")), KGuiItem(i18n("Cancel")) );
+ int choice = KMessageBox::questionYesNo( this, i18n("Do you really want to remove \"%1\"?").tqarg( currentItem->text(0) ), i18n("Remove Project File?"), KGuiItem(i18n("Remove")), KGuiItem(i18n("Cancel")) );
if ( choice == KMessageBox::No )
return;